
clear all
set more off

scalar def which_pc=1

if which_pc==1 {
	global folder=/*Insert here the path to your replication folder*/
	}
	

global USER_FOLDER="$folder"
global GID_CORE_DATA_FOLDER="$folder\core_section\dta"


*this should be the folders where you want to save the figures and tables:
global TABLES="$folder\Other_analysis"	
global CHARTS="$folder\Other_analysis"	


insheet using "$USER_FOLDER\D\other_data_from_istat\minimal_istat.csv", comma
rename year wave
merge m:1 wave using "$USER_FOLDER\D\other_data_from_istat\CPI_ITA.dta"
keep if _merge==3

bys wave: egen annual_index=mean(index)
bys wave: gen tokeep=_n
keep if tokeep==1

keep wave annual_index value
rename wave year

egen aux=mean(annual_index) if year==2015
egen auxb=mean(aux)
replace annual_index=(annual_index/auxb)*100
cap drop aux*
egen aux=mean(value) if year==2015
egen auxb=mean(aux)
gen real_wage_index=(annual_index*auxb)/value
cap drop aux*
keep year real_wage_index

save "$USER_FOLDER\D\other_data_from_istat\istat_real_index.dta", replace

*remember to create the subfolder Data\clean as explained in the readme file
u "$USER_FOLDER\Data\clean\GID_Data_Clean", replace

keep if age>24 & age<56 & TW>3 & Yr>0

gen female=sex=="F"
gen openend=type_contract=="I"
replace openend=. if year<1998

sum cpi if year==2016
local mm=r(mean)
gen cpi_2016=cpi/`mm'
gen LB=260*5*cpi_2016
gen UB=200000*cpi_2016

/*
tab year , sum(female)
tab year, sum(parttime)
tab year, sum(openend)
tab year , sum(Yr)
tab year if parttime==0, sum(Yr)
tab year if female==0, sum(Yr)
tab year if openend==1, sum(Yr)
tab year if parttime==0 & female==0, sum(Yr)
tab year if parttime==0 & openend==1, sum(Yr)
tab year if openend==1 & female==0, sum(Yr)
tab year if parttime==0 & openend==1 & female==0, sum(Yr)
*/

*all:
tab year, sum(Yr)
gen Yr_corrA=Yr
replace Yr_corrA=Yr*2 if parttime==1
gen Yr_corrB=Yr
replace Yr_corrB=Yr*1.5 if parttime==1
gen Yr_corrC=Yr
replace Yr_corrC=Yr*52/origweek
gen Yr_corrD=Yr
replace Yr_corrD=Yr*52/origweek
replace Yr_corrD=Yr_corrD*2 if parttime==1
gen Yr_corrE=Yr
replace Yr_corrE=Yr*52/origweek
replace Yr_corrE=Yr_corrE*1.5 if parttime==1
gen Yr_corrF=Yr
replace Yr_corrF=Yr*52/origweek
replace Yr_corrF=Yr_corrF*1.8 if parttime==1

gen Yr_corrG=Yr
replace Yr_corrG=Yr*52/origweek if openend==0
replace Yr_corrG=Yr_corrG*1.8 if parttime==1
replace Yr_corrG=. if openend==.


gen Yr_corrH=Yr
replace Yr_corrH=Yr*52/origweek if openend==0
replace Yr_corrH=Yr_corrH*2 if parttime==1
replace Yr_corrH=. if openend==.


gen Yr_corrI=Yr
replace Yr_corrI=Yr*52/origweek if TEMP_ever==1
replace Yr_corrI=Yr_corrI*1.8 if parttime==1
replace Yr_corrI=. if  TEMP_ever==.


gen Yr_corrJ=Yr
replace Yr_corrJ=Yr*52/origweek if TEMP_ever==0
replace Yr_corrJ=Yr_corrJ*2 if parttime==1
replace Yr_corrJ=. if  TEMP_ever==.


gen origweek_temp=origweek
replace origweek_temp=. if openend==. | openend==1

gen origweek_openend=origweek
replace origweek_openend=. if openend==. | openend==0

gen origweek_tempever=origweek
replace origweek_tempever=. if TEMP_ever==. | TEMP_ever==0

/*
tab year, sum(Yr)
tab year , sum(Yr_corrA)
tab year , sum(Yr_corrB)
tab year , sum(Yr_corrC)
tab year , sum(Yr_corrD)
tab year , sum(Yr_corrE)
tab year , sum(Yr_corrF)
*/

collapse Yr Yr_corr* parttime openend origweek* TEMP_ever female, by(year)
rename Yr realwage
rename Yr_corrA realwage_PT2
rename Yr_corrB realwage_PT1p5
rename Yr_corrC realwage_weeks_adj
rename Yr_corrD realwage_weeksadj_PT2
rename Yr_corrE realwage_weeksadj_PT1p5
rename Yr_corrF realwage_weeksadj_PT1p8
rename Yr_corrG realwage_weeksadjtemp_PT1p8
rename Yr_corrH realwage_weeksadjtemp_PT2
rename Yr_corrI realwage_weeksadjtev_PT1p8
rename Yr_corrJ realwage_weeksadjtev_PT2

*remember to create the subfolder Data\clean as explained in the readme file
save  "$USER_FOLDER\Data\clean\tempB.dta", replace

u "$USER_FOLDER\D\other_data_from_istat\istat_real_index.dta", replace
merge 1:1 year using "$USER_FOLDER\Data\clean\tempB.dta"

sort year
foreach vvv in realwage realwage_PT2 realwage_PT1p5 realwage_weeks_adj realwage_weeksadj_PT2 ///
				realwage_weeksadj_PT1p5 realwage_weeksadj_PT1p8 realwage_weeksadjtemp_PT1p8  realwage_weeksadjtemp_PT2 ///
				realwage_weeksadjtev_PT1p8 realwage_weeksadjtev_PT2{
				
				cap drop aux*
				sum `vvv' if year==2015
				gen ind_`vvv'=(`vvv'/r(mean))*100
				
				
				}

label var real_wage_index "ISTAT index"
label var ind_realwage "INPS raw"
label var ind_realwage_weeks_adj "INPS weeks adj."
label var ind_realwage_PT2 "INPS part time X 2"

label var ind_realwage_weeksadj_PT1p5 "weeks adj for all and PT X 1.5"
label var ind_realwage_weeksadj_PT1p8 "weeks adj for all  and PT X 1.8"
label var ind_realwage_weeksadj_PT2 "weeks adj for all and PT X 2"
label var ind_realwage_weeksadjtemp_PT1p8 "weeks adj for temp and PT X 1.8"
label var ind_realwage_weeksadjtemp_PT2 "weeks adj for temp and PT X 2"
label var ind_realwage_weeksadjtev_PT1p8 "weeks adj for tev and PT X 1.8"
label var ind_realwage_weeksadjtev_PT2 "weeks adj for tev and PT X 2"

gen temp_workers=1-openend
gen share_weeks=origweek/52
gen share_weeks_temp=origweek_temp/52
gen share_weeks_tempever=origweek_tempever/52
gen share_weeks_openend=origweek_openend/52
label var female "Female workers"
label var parttime "Part-time workers"
label var openend "Open-end workers"
label var share_weeks "Weeks worked/52"
label var share_weeks_temp "Weeks worked/52 (temp)"
label var share_weeks_tempever "Weeks worked/52 (one temp)"
label var share_weeks_openend "Weeks worked/52 (open end)"
label var TEMP_ever "Some Temp job"

save "$USER_FOLDER\D\other_data_from_istat\inps_istat_convergenceB.dta" , replace				

u "$USER_FOLDER\D\other_data_from_istat\inps_istat_convergenceB.dta" , replace	

label var openend "Open-end workers (RHS)"
label var share_weeks "Weeks worked/52 (RHS)"

label var share_weeks "Weeks worked/52"
label var temp_workers "Temporary workers (RHS)"
label var TEMP_ever "Some Temp job (RHS)"



*Figure 2
label var openend "Open-end workers (RHS)"
label var share_weeks "Weeks worked/52 (RHS)"
preserve 
scatter  female year, connect(l) || scatter  parttime year, connect(l) ///
	|| scatter  openend year , connect(l) yaxis(2) ///
	|| scatter  share_weeks year , connect(l) yaxis(2) , graphregion(color(white)) name(a, replace) ytitle("", axis(2))
graph export "$CHARTS\shares.pdf", name(a) replace
restore

*Figure A7
preserve 
keep if year>1999
scatter  real_wage_index year, connect(l) || scatter  ind_realwage year, connect(l) ///
	|| scatter  ind_realwage_weeksadj_PT1p5 year , connect(l) ///
	|| scatter  ind_realwage_weeksadj_PT1p8 year , connect(l) ///
	|| scatter  ind_realwage_weeksadj_PT2 year , connect(l) , graphregion(color(white)) name(a, replace)
graph export "$CHARTS\convergenceB.pdf", name(a) replace
restore



