/*Produces regression of volatility on causes of separation*/
***Nov 1: Added # of jobs to main specificaitons (LP)

clear all
set more off
set matsize 800
cap log close

scalar def which_pc=1

if which_pc==1 {
	global folder=/*Insert here the path to your replication folder*/
	}
	


*this should be the folders where you want to save the figures and tables:
global TABLES="$folder\Other_analysis"	
global CHARTS="$folder\Other_analysis"	


global run_main_results = "yes"

********************************************************************************	
*Table 1
********************************************************************************

if "$run_main_results" == "yes"{
	*remember to create the subfolder Data\clean as explained in the readme file
	use $folder\Data\clean\GID_Data_Clean_plus.dta , replace

	keep if age>=25 & age<=55 & TW>3

	xtset id year
	g dy=log(Yr)-log(L.Yr)
	g dysq=dy^2
	g j2j=firm_ID!=L.firm_ID
	*g dweeks= weeks_worked_main-L.weeks_worked_main
	g dweeks= TW-L.TW
	replace dweeks=dweeks/52
	gen pos_week=dweeks>0
	replace pos_week=. if dweeks==.
	gen neg_week=dweeks<0
	gen dweeks_plus=dweeks*(pos_week)
	gen dweeks_minus=dweeks*(neg_week)


	g FT2PT= (parttime==1 & L.parttime==0)
	g PT2FT= (parttime==0 & L.parttime==1)
	g S2S=sector_ateco!=L.sector_ateco
	gen female=sex=="F"
	*gen precario= (OPEN_main==0 & L.OPEN_main==1)
	g agesq=age*age/100
	g log_dysq=log(dysq)

	*generate rolling variance
	gen roll3_dysq=(l.dysq+dysq+f.dysq)/3
	replace roll3_dysq=. if Cause_separation==5

	*correct rolling variance
	cap drop aux
	bys id (year): egen aux=mean(dy)
	gen roll3_correct=((l.dy-aux)^2 + (dy-aux)^2 + (f.dy-aux)^2)/3
	replace roll3_correct=. if Cause_separation==5

	*correct rolling variance
	cap drop aux
	bys id (year): gen aux=(l.dy+dy+f.dy)/3
	gen roll3_correct_B=((l.dy-aux)^2 + (dy-aux)^2 + (f.dy-aux)^2)/3
	replace roll3_correct_B=. if Cause_separation==5
	
	

	label def ccss  1 "Cause Separation: Layoff" 2 "Cause Separation: Administrative" 3 "Cause Separation: Quit" /// 
				4 "Cause Separation: End Contract" 5 "Cause Separation: Death" 6 "Cause Separation: Other" , replace
	label value Cause_separation ccss

	replace Cause_separation =0 if ever_separated ==0 & year >2004
	replace Cause_separation =0 if Cause_separation ==. & year>2004
	replace Cause_separation =0 if Cause_separation ==2 & year>2004

	label var age "Age"
	label var agesq "Age squared"
	label var female "Female"

	recode Occupation (1 5 = 0) (2 = 1) (3 = 4) (4 = 3) (6 = 2), gen(Occ_reg)
	label def ooccrr 0 "Occ: Apprentship/Other" 1 "Occ: Blue collar" 2 "Occ: White collar" ///
			3 "Occ: Middle manager" 4 "Occ: Executive manager"
	label value Occ_reg ooccrr

	label var FT2PT "Full time to part time"
	label var PT2FT "Part time to full time"
	label var j2j "Job switcher"
	label var S2S "Sector switcher"
	label var dweeks "Change in weeks worked/52"
	label var pos_week "Weeks worked increased"
	label var neg_week "Weeks worked decreased"

		
		local vvv roll3_correct_B 
		eststo clear
		/*
		eststo: reg `vvv' i.Cause_separation age agesq female i.year i.region i.Occ_reg i.dim FT2PT PT2FT if year>2004,cluster(id)
		eststo: reg `vvv' i.Cause_separation age agesq female i.year i.region i.Occ_reg i.dim FT2PT PT2FT j2j  if year>2004,cluster(id)
		eststo: reg `vvv' i.Cause_separation age agesq female i.year i.region i.Occ_reg i.dim FT2PT PT2FT j2j S2S  if year>2004,cluster(id)
		*/
		eststo: reg `vvv' i.Cause_separation age agesq female i.year i.region i.Occ_reg i.dim parttime FT2PT PT2FT j2j S2S dweeks Nobs if year>2004,cluster(id)
		sum `vvv' if e(sample) & Cause_separation==0
		estadd scalar mean_vol = r(mean)
		test 1.Cause_separation-4.Cause_separation=0
		estadd scalar p_14=r(p) 
		eststo: areg `vvv' i.Cause_separation age agesq /*female*/ i.year /*i.region*/ i.Occ_reg parttime i.dim FT2PT PT2FT j2j S2S dweeks Nobs if year>2004,a(id) cluster(id)
		sum `vvv' if e(sample) & Cause_separation==0
		estadd scalar mean_vol = r(mean)
		test 1.Cause_separation-4.Cause_separation=0
		estadd scalar p_14=r(p)
		
		esttab est* using "$TABLES/reg_vol_with_part_simpler_`vvv'", csv  star(* 0.10 ** 0.05 *** 0.01) ///
								cells(b(star fmt(%9.3g)) se(par fmt(%9.3g))) stats( r2_a  N mean_vol p_14, labels(  "Adj. R2" "Observations" "Mean volatility stayers" "P-value Layoff=End-contract"))  nonotes replace label collabels(none)

									
		esttab est* using "$TABLES/reg_vol_with_part_simpler_short_`vvv'", ///
							keep(*Cause_separation age agesq female *Occ_reg j2j S2S parttime FT2PT PT2FT dweeks) ///
							tex  star(* 0.10 ** 0.05 *** 0.01) ///
							cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
							stats( r2_a  N mean_vol p_14, labels(  "Adj. R2" "Observations" "Mean volatility stayers" "P-value Layoff=End-contract") fmt(%9.3f %9.3g %9.3g %9.3g) ) ///
							  nobase noomit nonotes nodep nomti replace label collabels(none)		


}

********************************************************************************	
*Figure A.17
********************************************************************************
preserve
drop if Cause_separation==.
drop if Cause_separation==0
gen CS = Cause_separation
replace CS=5 if CS==6
keep CS year
tab CS, gen(CCSS)
collapse CCSS*, by(year)
connect CCSS* year, graphregion(color(white)) legend(label(1 "Firing") label(2 "Quit") label(3 "End Contract") label(4 "Other"))
graph export "$CHARTS\share_sep_by_cause.pdf", name(a) replace
restore

