
%% read data from OECD
% data downloadable at: https://data.oecd.org/lprdty/gdp-per-hour-worked.htm
tab = readtable('OECD_gdp_per_hour_worked.csv');

select_ITA = strcmp(tab.LOCATION,'ITA') & strcmp(tab.MEASURE,'USD') & tab.TIME>=1985 & tab.TIME<=2016;
select_G7 = strcmp(tab.LOCATION,'G-7') & strcmp(tab.MEASURE,'USD') & tab.TIME>=1985 & tab.TIME<=2016;

GDPHRWKD_G7 = tab.Value(select_G7);
GDPHRWKD_ITA = tab.Value(select_ITA);
GDPHRWKD_G7_ind = 100*GDPHRWKD_G7/GDPHRWKD_G7(1);
GDPHRWKD_ITA_ind = 100*GDPHRWKD_ITA/GDPHRWKD_ITA(1);


clear tab

%% read recession dates from OECD
% data downloadable at https://www.oecd.org/sdd/leading-indicators/oecdcompositeleadingindicatorsreferenceturningpointsandcomponentseries.htm
tab = readtable('CLI-components-and-turning-points.csv','FileType','spreadsheet');
tab(1,:) = [];
tab.Time = datetime(year(tab.Time),day(tab.Time),eomday(year(tab.Time),day(tab.Time))); % fix dates
recessions_start = tab.Time(tab.ITA==1);
recessions_end = tab.Time(tab.ITA==-1);
if recessions_end(1)<recessions_start(1)
    recessionsdata = [recessions_start recessions_end(2:end)];
end
clear tab recessions_start recessions_end

% note: there is no recession in 1985 according to this dating. Otherwise
% identical.
%% make a simple graph
year = datetime(1985:2016,1,1);
figure; 
plot(year,[GDPHRWKD_ITA_ind GDPHRWKD_G7_ind],'LineWidth',2); 
ylabel('index')
datetick; 
recessionplot('recessions',recessionsdata); 
xlim([year(1) year(end)]);
legend('Italy','G-7','Location','NorthWest');
