
use "$../dta/GID_Data_Core_new_4w.dta" , replace

// compare 2016 earnings distribution with 1985 distribution of covariates
global baseyear = 1985 
global thisyear = 2016

keep if year == $baseyear | year == $thisyear

gen age = year - y_birth
gen year$baseyear = year == $baseyear
sum year$baseyear if (year== $baseyear | year ==  $thisyear) & inrange(age,25,60)
gen p$baseyear = r(mean)

gen ly = log(wage_inc)

sum ly
gen x16 = r(mean) - 2*r(sd) + _n*(r(sd)*4)/400 if _n<=400 // choose the range for density estimation
kdensity ly if year==$thisyear & inrange(age,25,60), gen(d16) at(x16) nogr
lab var d16 "actual density in $thisyear"
lab var x16 "log earnings"

// basic DFL counterfactual; only use age and sex interacted
cap drop *_1
reg year$baseyear ibn.age#male if (year== $baseyear | year == $thisyear) & inrange(age,25,60), noconst
predict phat_1, xb
gen wt_1 = (phat_1/(1-phat_1))/(p$baseyear /(1-p$baseyear ))
sum wt_1 if year == $thisyear & inrange(age,25,60)
kdensity ly if year==$thisyear & inrange(age,25,60) [aw=wt_1], gen(x16cx_1 d16cx_1) at(x16)  nogr
label var d16cx_1 "counterfactual distribution"
scatter d16 d16cx_1 x16,c(l l) s(i i) clp(solid dash) graphr(c(white)) clp(solid dash) legend(size(small) reg(lc(white)) cols(1)) saving(a,replace) ylabel(0(.2)1.2) scale(1.3) title("age/gender only") legend(size(*1.2))

// basic DFL counterfactual; use age, sex, and part time work
cap drop *_2
probit year$baseyear ibn.age#male#parttime if (year==$baseyear | year == $thisyear) & inrange(age,25,60), noconst
predict phat_2, pr
gen wt_2 = (phat_2/(1-phat_2))/(p$baseyear/(1-p$baseyear))
sum wt_2 if year == $thisyear & inrange(age,25,60)
kdensity ly if year==$thisyear & inrange(age,25,60) [aw=wt_2], gen(x16cx_2 d16cx_2) at(x16)  nogr
label var d16cx_2 "counterfactual distribution"
scatter d16 d16cx_2 x16,c(l l) s(i i) clp(solid dash) graphr(c(white)) clp(solid dash) legend(size(small) reg(lc(white)) cols(1)) saving(b,replace) ylabel(0(.2)1.2) scale(1.3) title("age/gender & part-time") legend(size(*1.2))

graph combine a.gph b.gph, graphr(c(white))
graph export "$folder\Slides\slides_figures\cfactual_distr.pdf", as(pdf) replace