// this file analyzes the panel dataset. the output is:
// 1. hours of work per week in part-time and full-time jobs
// 2. transition probabilities between work status (private/public sector, self employed, and not employed).
// 3. transition probabilities between contract types (fixed-term/permanent, self-employed, and not employed).

use "shiw_panel.dta", clear

// hours by employment status (full-/part-time), Figure A.16
preserve
graph set window fontface "Times New Roman"
keep if inrange(age,25,55)
collapse (mean) hours_worked [aweight=peso], by(anno partime)
drop if partime ==.
reshape wide hours_worked , i(anno) j(partime)
label var hours_worked0 "full-time job"
label var hours_worked1 "part-time job"
label var anno "year"
tw (connected hours_worked* anno, msymbol(s o) ///
		color(red blue) lpattern(solid dash) lwidth(thick thick)), ///		
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) size(large) cols(1) symxsize(7) region(color(none))) ///
		ytitle("Hours per week", size(large)) ///
		title("", color(black) size(medium)) ylabel(0(5)50,labsize(large)) xtitle(" ", margin(small)) xlabel(,labsize(large))
graph export "hours_by_fptime.pdf", replace 
restore

// summary stat for the panel aspect
preserve
keep if inrange(age,25,55)
collapse (count) counter = anno, by(id)
tab counter
sum counter, d
restore


// two-year transition probabilities in work status by sex
preserve
keep if inrange(age,25,55)
keep if anno>=2000
todummy work_status_short , pre(work_status_) levels
gen lag_work_status_short = l2.work_status_short
label val lag_work_status_short WORK_STATUS_SHORT
drop work_status_short
collapse (mean) work_status_* if inrange(age,25,55) [aweight=peso], ///
	by(sex lag_work_status_short)
	
drop if lag_work_status_short == .
save transition_prob_by_sex, replace
export delimited using "work_status_transitions_probabilities_by_sex", replace
restore

// two-year transition probabilities in contract type: permanent, temporary/fixed-term, self-employed, and not employed
preserve
keep if anno>=2000
recode contratt (1 = 1) (2 3 = 2), gen(contract_type)
replace contract_type = 4 if contract_type == . & work_status_short == 4
replace contract_type = 3 if work_status_short == 3
label define CONTRACT_TYPE 1 "permanent" 2 "temporary/fixed-term" ///
	3 "self employed" 4 "not employed" 
label val contract_type CONTRACT_TYPE

gen prev_contract_type = l2.contract_type
label val prev_contract_type CONTRACT_TYPE

todummy contract_type, pre(contract_type_) levels
collapse (mean) contract_type_* if inrange(age,25,55) [aweight=peso], by(sex prev_contract_type)
drop if prev_contract_type ==.
save transition_contract, replace
export delimited using "contract_type_transitions_probabilities_by_sex", replace
restore