// this file prepares the panel data for analysis.
// it uses comp as a starting point and adds data on income, salaried and self employed work,
// work status, and contract information

// prepare the data from all the linked files
use "comp", clear
drop if anno <=1987 // keep only panel

keep nquest nord anno sesso eta qualp7n qualp10 nonoc settp9 settp11 nordp

rename sesso sex
rename eta age
rename qualp7n work_status
rename settp11 industry11
rename settp9 industry9

merge 1:1 nquest nord anno using linking_file, keepusing(id)
drop _merge

merge 1:1 nquest nord anno using rper
drop if anno<=1987
drop _merge

merge n:1 anno using defl
drop if _merge == 2
gen real_yl = yl*rival
gen real_yt = yt*rival
gen real_ym = ym*rival
drop ym yt yl defl _merge
merge n:1 anno nquest using PESO
drop if _merge == 2
drop _merge

gen public_sector = industry11 == 9
replace public_sector = industry9 == 8 if inrange(anno,1989,1991)

replace work_status = 8 if work_status == 7
label define WORK_STATUS 1 "blue-collar" 2 "office worker/teacher" 3 "junior manager" 4 "manager" ///
	5 "member of profession" 6 "sole proprietor" 7 "freelancer" 8 "not employed"
label val work_status WORK_STATUS

label define SEX 1 "men" 2 "women"
label val sex SEX

merge 1:1 anno nquest nord using ldip_clean, keepusing(contratt partime oretot attivp mesilav)
drop if _merge == 2
drop _merge

label define CONTRATT 1 "permanent" 2 "fixed-term" 3 "temporary"
label val contratt CONTRATT

rename oretot hours_employed
rename attivp employed
rename mesilav months_employed
merge 1:1 anno nquest nord using linb_clean, keepusing(profn oretot attivp mesilav)
drop if _merge == 2
drop _merge
rename oretot hours_self_employed
rename attivp self_employed
rename mesilav months_self_employed

// adjust for freelancers (many) and members of the profession (few)
replace work_status = 7 if work_status == 6 & profn == 3
replace work_status = 5 if work_status == 6 & profn == 1

recode work_status (1 2 3 4 = 1) (5 6 7 = 3) (8 = 4), gen(work_status_short)
replace work_status_short = 2 if work_status_short == 1 & public_sector == 1
label define WORK_STATUS_SHORT 1 "private sector" 2 "public sector" 3 "self employed" 4 "not employed"
label val work_status_short WORK_STATUS_SHORT

order id anno real*
sort id anno

keep nquest nord nordp real* peso id anno employed self_employed hours_employed /// 
	hours_self_employed profn partime industry9 industry11 public_sector ///
	work_status* sex age months_employed months_self_employed contratt

replace hours_employed = 0 if hours_employed == .
replace hours_self_employed = 0 if hours_self_employed == .
gen hours_worked = hours_employed + hours_self_employed

replace months_employed = 0 if months_employed == .
replace months_self_employed = 0 if months_self_employed == .
gen months_worked = months_employed + months_self_employed
replace months_worked = 12 if months_worked> 12

gen real_w = (real_yl + real_ym + real_yt)/(hours_worked*months_worked*52/12)

xtset id anno, yearly

save "shiw_panel.dta", replace