% use continuous time Markov chains to calculate transition probabilities
% between work status (private sector, public sector, self employed, not
% employed).
clear
close all

% read estimated two-year probabilities
read_work_status_prob_sex;

% generator matrices for markov chains
tm_men = 0.5*logm(TM_men);
tm_women = 0.5*logm(TM_women);

% plot transition probabilities using matrix exponents.
contract_type = {'private sector','public sector','self employed','not employed'};
T = 241;
figure; tiledlayout(4,1,'TileSpacing','compact','Padding','none');
for j = 1:length(contract_type)
    x = zeros(T,4);
    for i = 1:T
        x(i,:) = 100*(1:4==j)*expm(1/12*(i-1)*tm_men);
    end
    
    nexttile;
    p = plot(((1:T)-1)/12,x,'LineWidth',2);
    p(1).Marker = 'o';
    p(1).MarkerIndices=1:60:T;
    p(1).MarkerFaceColor = p(1).Color;
    p(2).Marker = '^';
    p(2).MarkerIndices=1:60:T;
    p(2).MarkerFaceColor = p(2).Color;
    p(3).Marker = 's';
    p(3).MarkerIndices=1:60:T;
    p(3).MarkerFaceColor = p(3).Color;
    p(4).Marker = 'd';
    p(4).MarkerIndices=1:60:T;
    p(4).MarkerFaceColor = p(4).Color;
    title(contract_type{j},'Fontweight','normal');
    ylim([0 100]);
    grid on;
end
lgd = legend(contract_type,'Location','NorthEast','Orientation',...
             'Horizontal','NumColumns',2);
lgd.Layout.Tile = 'south';   
xlabel('years');
set(gcf,'PaperSize',[4 6]);

figure; tiledlayout(4,1,'TileSpacing','compact','Padding','none');
for j = 1:length(contract_type)
    x = zeros(T,4);
    for i = 1:T
        x(i,:) = 100*(1:4==j)*expm(1/12*(i-1)*tm_women);
    end
    
    nexttile;
    p = plot(((1:T)-1)/12,x,'LineWidth',2);
    p(1).Marker = 'o';
    p(1).MarkerIndices=1:60:T;
    p(1).MarkerFaceColor = p(1).Color;
    p(2).Marker = '^';
    p(2).MarkerIndices=1:60:T;
    p(2).MarkerFaceColor = p(2).Color;
    p(3).Marker = 's';
    p(3).MarkerIndices=1:60:T;
    p(3).MarkerFaceColor = p(3).Color;
    p(4).Marker = 'd';
    p(4).MarkerIndices=1:60:T;
    p(4).MarkerFaceColor = p(4).Color;

    title(contract_type{j},'Fontweight','normal');
    ylim([0 100]);
    grid on;
end
lgd = legend(contract_type,'Location','NorthEast','Orientation',...
             'Horizontal','NumColumns',2);
lgd.Layout.Tile = 'south';   
xlabel('years');
set(gcf,'PaperSize',[4 6]);

