*
clear all
set more off

*use "C:\data\Losai\Losai\02.DIPENDENTI\rapportilavoro_19852012.dta" , replace

*path to dropbox folder GID_QE (where do files are and clean data will be saved)
global USER_FOLDER="C:\Users\" /*instert your path here*/

*Need to have subfolder \Programs\Prepare_INPS_Data\ with do files for this to run smoothly

*path to raw data 
global RAW_DATA=/*instert path To losai raw data here*/

*the folder must contain subfolders:
*- \01.ANAGRAFICA\ (with demographic dataset)
*- \02.DIPENDENTI\ (with job-level data)
*and so on
*note that this structure is the default one when you unzip the data 
*provided by the ministry 
global MODIFIED_DATA= /*insert path to folder where dta should be saved*/


global GID_CORE_DATA_FOLDER=/*where you want the data for core analysis*/


use "$RAW_DATA\02.DIPENDENTI\rapportilavoro_19852016.dta", replace

merge m:1 Anno using "$MODIFIED_DATA\threshold.dta", keep(match master)
gen aux=Retribuzione_imponibile/Giornate_retribuite
*create flags for potential topcoded records:
gen flag_tc=(aux>th&aux!=.)
gen flag_tc1=(aux>th-1&aux!=.)
label var flag_tc "Flag for top coded obs"
label var flag_tc1 "Flag for top coded obs (using threshold minus 1)"
label var th "Threshold topcoding year specific"

cap drop _merge
merge m:1 ID_LAVORATORE using "$MODIFIED_DATA\anagr_unique.dta" 
tab _merge
drop if _merge==2


sort ID_LAV Anno
tab Anno _merge, row
tab Anno SESSO, miss row
gen miss_b_year=ANNO_NASC==.
tab Anno miss_b_year, row

keep if _merge==3

tab Anno _merge, row
tab Anno miss_b_year, row
tab Anno SESSO, miss row

drop _merge miss_b_year
drop aux
*cap drop _merge
*merge m:1 ID_LAVORATORE Anno using "unemp_benefit.dta" 
*drop if _merge==2


bys ID_LAV Anno (Retribuzione_imponibile): gen Nobs=_N
bys ID_LAV Anno (Retribuzione_imponibile): gen nobs=_n

bys ID_LAV Anno (Retribuzione_imponibile): egen Y=total(Retribuzione_imponibile)
tab Anno if nobs==1, sum(Y)

gen parttime=0
replace parttime=1 if Tipo_ora=="P" | Tipo_ora=="V" | Tipo_ora=="M"

gen OPEN=Tipo_contratto=="I"
replace OPEN=. if Anno<1998

gen weeks=Settimane_retribuite 
replace weeks=Settimane_utili if parttime==1

sort ID_LAV Anno Retribuzione_imponibile
by ID_LAV Anno (Retribuzione_imponibile): gen partB=parttime[_N]
by ID_LAV Anno (Retribuzione_imponibile): gen OPEN_main=OPEN[_N]
cap drop aux
by ID_LAV Anno (Retribuzione_imponibile): egen aux=mean(OPEN)
gen TEMP_ever=aux<1
replace TEMP_ever=. if OPEN==.
cap drop aux
by ID_LAV Anno (Retribuzione_imponibile): egen totflag_tc=total(flag_tc)
by ID_LAV Anno (Retribuzione_imponibile): egen totflag_tc1=total(flag_tc1)

replace parttime=partB
drop partB


bys ID_LAV Anno (Retribuzione_imponibile): egen TW=total(weeks)

sort ID_LAV Anno ID_AZIENDA
bys ID_LAV Anno ID_AZIENDA: gen nnwithinaz=_n
keep if nnwithinaz==1
bys ID_LAV Anno: gen Nfirm=_N

rename ID_AZIENDA firm_ID

cap drop _merge
merge m:1 firm_ID Anno using "$MODIFIED_DATA\firm_data.dta"
drop if _m==2
drop _merge


gen Cause_separation=.

*fired
replace Cause_separation=1 if Motivo_cessazione=="1A" | Motivo_cessazione=="1D" | ///
			Motivo_cessazione=="1H" | Motivo_cessazione=="1L" 

*formal
replace Cause_separation=2 if  Motivo_cessazione=="2" | Motivo_cessazione=="2T" | Motivo_cessazione=="1M"

*quit
replace Cause_separation=3 if Motivo_cessazione=="1B" | Motivo_cessazione=="1G" 

*end contract
replace Cause_separation=4 if Motivo_cessazione=="1C" | Motivo_cessazione=="1N"

*death
replace Cause_separation=5 if Motivo_cessazione=="4"

*other
replace Cause_separation=6 if Motivo_cessazione=="1E" | Motivo_cessazione=="1F" | ///
			Motivo_cessazione=="2E" |  ///
			Motivo_cessazione=="3" | Motivo_cessazione=="9" | Motivo_cessazione=="1P"

label def ccss  1 "Firing" 2 "Only formal not real" 3 "Quit" /// 
			4 "End Contract" 5 "Death" 6 "Other" , replace
label value Cause_separation ccss
label var Cause_separation "Reason separation aggregated"
			
/*
1A	Licenziamento (anche se avvenuto per giustificato motivo oggettivo)
1B	Dimissioni
1C	Fine contratto
1D	Licenziamento per giusta causa o giustificato motivo soggettivo
1E	Cessazione della contribuzione figurativa correlata per i dipendenti FS.
1F	Conclusione del periodo di regolarizzazione di emersione ai sensi dell’art. 5 del D.lgs. n.109/2012. Circolari n. 113 del 14/9/2012 e n. 118 del 28/9/2012.
1G	Risoluzione consensuale
1H	Risoluzione consensuale in sede di conciliazione (art. 7 comma 7 L.604/1966 come modificato dalla L. 92/2012)
1L	Licenziamento per esodo incentivato (art. 4, commi 1-7 ter, L. 92/2012)
1M	“Licenziamento” per cambio appalto (art. 2, co. 34, lett. A), l. 92/2012
1N	Interruzione di rapporti di lavoro a tempo indeterminato, nel settore edile, per
completamento delle attività e chiusura di cantiere.
1P MISSING EXPLANATION, ONLY 25 obs
2	Variazioni aziendali che comportano la cessazione e la conseguente presa in carico del lavoratore su una diversa matricola, nell’ambito dello stesso soggetto giuridico
2E	Cessazione per i dipendenti FS ed accesso al Fondo di Solidarietà
2T	Cessazione e conseguente assunzione in carico di lavoratori a seguito di trasferimento d’azienda o di ramo di essa, a seguito di cessione individuale di contratto da parte di un’altra azienda ovvero di passaggio diretto nell’ambito di gruppo d’imprese che comportano comunque il cambio di soggetto giuridico
3	Sospensione o aspettativa sindacale/elettorale
4	Decesso
9	Altre motivazioni
*/

encode Motivo_cessazione, generate(end_reason) label(eerr)
encode Motivo_assunzione, generate(start_reason) label(ssrr)
drop Motiv*


sort ID_LAV Anno Retribuzione_imponibile


cap drop aux
gen aux=Cause_separation==1
replace aux=. if Cause_separation==.
replace aux=0 if aux==. & Anno>2004
by ID_LAV Anno (Retribuzione_imponibile): egen ever_fired=mean(aux)
replace ever_fired=ever_fired>0 if Anno>2004 
by ID_LAV Anno (Retribuzione_imponibile): gen main_fired=aux[_N]
cap drop aux
gen aux=Cause_separation==3
replace aux=. if Cause_separation==.
replace aux=0 if aux==. & Anno>2004
by ID_LAV Anno (Retribuzione_imponibile): egen ever_quit=mean(aux)
replace ever_quit=ever_quit>0 if Anno>2004 
by ID_LAV Anno (Retribuzione_imponibile): gen main_quit=aux[_N]
cap drop aux
gen aux=Cause_separation==4
replace aux=. if Cause_separation==.
replace aux=0 if aux==. & Anno>2004
by ID_LAV Anno (Retribuzione_imponibile): egen ever_end_contract=mean(aux)
replace ever_end_contract=ever_end_contract>0 if Anno>2004 
by ID_LAV Anno (Retribuzione_imponibile): gen main_end_contract=aux[_N]
cap drop aux
gen aux=(Cause_separation==2 | Cause_separation==5 | Cause_separation==6) 
replace aux=. if Cause_separation==.
replace aux=0 if aux==. & Anno>2004
by ID_LAV Anno (Retribuzione_imponibile): egen ever_sep_other=mean(aux)
replace ever_sep_other=ever_sep_other>0 if Anno>2004 
by ID_LAV Anno (Retribuzione_imponibile): gen main_sep_other=aux[_N]
cap drop aux
gen aux=Data_cessazione!="0000"
by ID_LAV Anno (Retribuzione_imponibile): egen ever_separated=mean(aux)
replace ever_separated=ever_separated>0  
by ID_LAV Anno (Retribuzione_imponibile): gen main_separated=aux[_N]
cap drop aux

*count if main_fired ==1 | main_sep_other ==1 | main_quit==1 | main_end_contract==1
*count if ever_fired ==1 | ever_sep_other ==1 | ever_quit==1 | ever_end_contract==1

drop OPEN

save "$USER_FOLDER\Data\clean\individual_contracts.dta", replace
u "$USER_FOLDER\Data\clean\individual_contracts.dta", replace


*save "$MODIFIED_DATA\individual_contracts.dta", replace
*u "$MODIFIED_DATA\individual_contracts.dta", replace

*generate id-year level dataset:
keep if nobs==Nobs
drop nobs
drop weeks
drop nnwithinaz

label var Nobs "Number of records in year t"
label var totflag_tc "Number of top coded records in year t"
label var totflag_tc1 "Number of top coded records in year t (using threshold minus 1)"
label var Y "Total income in year t (retribuzione imponbile)"
label var parttime "Main job was part-time"
label var TW "Total weeks worked"
label var Nfirm "Number of firms with records in year t"
label var flag_tc "Flag for top coded obs in main job "
label var flag_tc1 "Flag for top coded obs (using threshold minus 1) in main job "
label var OPEN_main "Main contract is open end"
label var TEMP_ever "At least one contract is not open end"
label var ever_end_contract "At least one separation due to end_contract"
label var ever_fired "At least one separation due to firing"
label var ever_quit "At least one separation due to quit"
label var ever_sep_other "At least one separation due to other reason"
label var ever_separated "At least one separation"
label var main_end_contract "Main job separation due to end_contract"
label var main_fired "Main job separation due to firing"
label var main_quit "Main job separation due to quit"
label var main_sep_other "Main job separation due to other reason"
label var main_separated "Main job separation"
label var TW "total weeks worked (bounded at 52)"


gen age=Anno-ANNO_NASC
drop if age<15
drop if age>75
label var age "Age (year - b_year)"
*drop if SESSO=="F"
gen origweek=TW
label var origweek "Total weeks worked (unbounded)"
replace TW=1 if TW==0 & Y>0
replace TW=52 if TW>52
*drop if TW==0
*drop if Y==0
rename Anno wave
cap drop _merge
merge m:1 wave using "$MODIFIED_DATA\CPI_ITA", keep(match master)
drop _merge
rename wave year
label var year "Year"
rename value cpi
label var cpi "CPI Index (2010-100)"
gen Yr=Y/cpi*100
rename ID_LAV id
sum year


label var sector_ateco "Ateco 2002 (up to 2004 included) or 2007 (after)"
label var id "Individual identifier"
rename Tipo_orario Type_working_schedule 
label var Type_working_schedule "Type working schedule main job"
rename Qualifica Occupation 
label var Occupation "Occupation main job"
replace Occupation="Other" if Occupation=="Altro"
replace Occupation="Apprentship" if Occupation=="Apprendista"
replace Occupation="Manager (high-level)" if Occupation=="Dirigente"
replace Occupation="WhiteC" if Occupation=="Impiegato"
replace Occupation="BlueC" if Occupation=="Operaio"
replace Occupation="Manager (middle-level)" if Occupation=="Quadro"
rename Giornate_retribuite days_worked_main  
label var days_worked_main "Days worked main job"
rename Settimane_retribuite weeks_worked_main 
label var weeks_worked_main "Weeks worked main job"
rename Settimane_utili weeks_worked_adj_main 
label var weeks_worked_adj_main "Weeks worked adjusted by working schedule main job"
rename Tipo_politica type_policy
label var type_policy "type policy connected to contract main job"
rename Data_assunzione start_date
label var start_date "Date start main job (from 2005)"
rename Data_cessazione end_date
label var end_date "Date end main job"
label var start_reason "Reason start main job (from 2005)"
label var end_reason "Reason end main job (from 2005)"
label var firm_ID "ID firm main job"
rename ANNO_NASC y_birth 
label var y_birth "Year of birth"
rename ANNO_MORTE y_death 
label var y_death "Year of death"
rename SESSO sex
label var sex "Sex"

drop SEGNALE_CF
drop ID_OLD_LAVORATORE

rename REGIONE region_residence 
encode region_residence, gen(aux) label(rr)
drop region_residence
rename aux region_residence
label var region_residence "Region of residence"

cap drop aux
encode type_policy, gen(aux) label(ttpp)
drop type_policy
rename aux type_policy
label var type_policy " type policy connected to contract main job"


cap drop aux
encode Type_working_schedule, gen(aux) label(ttwwss)
drop Type_working_schedule
rename aux Type_working_schedule
label var Type_working_schedule "Type working schedule main job"


rename Tipo_contratto type_contract
cap drop aux
encode type_contract, gen(aux) label(ttwwss)
drop type_contract
rename aux type_contract
label var type_contract "type of contract main job"


cap drop aux
encode Occupation, gen(aux) label(oooccc)
drop Occupation
rename aux Occupation
label var Occupation "Occupation main job"

cap drop aux

label var Yr "Real income in 2010 euros"

rename Retribuzione_imponibile  income_main
label var income_main "Income from main job"
order id year
sort id year 
xtset id year 

/*
local my=r(min)
local MY=r(max)
sort year
gen cutlow=.
forvalues jj=`my'(1)`MY'{
	_pctile Yr if year==`jj' & parttime==0, p(2.5)
	replace cutlow=r(r1) if year==`jj'
	local mmmm=r(r1)
	disp "`jj' cut `mmmm'"
}
*/
*save temp_Aug1_top_coding, replace

save "$USER_FOLDER\Data\clean\GID_Data_Clean_plus", replace












