
clear all
set more off
set matsize 800
cap log close

scalar def which_pc=1	



if which_pc==1 {
	global folder=/*Insert here the path to your replication folder*/
	}

*this should be the folder where you want to save the tables:
global TABLES="$folder\Other_analysis"	

// Define some common charactristics of the plots 
	global xtitlesize =   "large" 
	global ytitlesize =   "large" 
	global xlabsize =     "large" 
	global ylabsize =     "large" 
	global titlesize  =   "large" 
	global subtitlesize = "medium" 
	global formatfile  =  "pdf"
	global fontface   =   "Times New Roman"
	global marksize =     "medium"	
	global legesize =     "large"	


***************FIGURE 13
*remeber to create the subfolder Data\clean as explained in the readme file
*****Earnings vs hourly earnings - variance decomposition
use $folder\Data\clean\GID_Data_Clean_plus.dta if age>=25 & age<=55 & TW>3, replace

gen hours=40*weeks_worked_main*(parttime==0)+40*weeks_worked_adj_main*(parttime==1)

g logy=log(income_main/(cpi/100))
g logw=log((income_main/(cpi/100))/(hours))
g logh=log((hours))

gegen wm=mean(logw),by(year)
gegen hm=mean(logh),by(year)
g ccc=(logh-hm)*(logw-wm)

xtset id year
g dlogy=d.logy
g dlogw=d.logw
g dlogh=d.logh
gegen dwm=mean(dlogw),by(year)
gegen dhm=mean(dlogh),by(year)
g ddd=(dlogh-dhm)*(dlogw-dwm)

gcollapse (sd) v_w=logw v_y=logy v_h=logh v_dw=dlogw v_dy=dlogy v_dh=dlogh (mean) cov=ccc covd=ddd,by(year)

replace v_w=v_w^2
replace v_y=v_y^2
replace v_h=v_h^2
replace v_dw=v_dw^2
replace v_dy=v_dy^2
replace v_dh=v_dh^2

gen twice_cov =2*cov
gen twice_covd=2*covd

lab var v_w "Var(log(w))"
lab var v_h "Var(log(h))"
lab var v_y "Var(log(Y))"
lab var v_dw "Var({&Delta}log(w))"
lab var v_dh "Var({&Delta}log(h))"
lab var v_dy "Var({&Delta}log(Y))"

lab var twice_cov "2Cov(log(h),log(w))"
lab var twice_covd "2Cov({&Delta}log(h),{&Delta}log(w))"
lab var year "Year"

graph bar (asis) v_w v_h twice_cov, over(year,label(labsize(vsmall) angle(45))) stack graphr(c(white)) legend(cols(3)) ///
bar(1,color(black)) bar(2,color(white) lcolor(black)) bar(3,color(gray)) saving(A,replace)
graph bar (asis) v_dw v_dh twice_covd,over(year,label(labsize(vsmall) angle(45))) stack graphr(c(white)) legend(cols(3) size(small)) ///
bar(1,color(black)) bar(2,color(white) lcolor(black)) bar(3,color(gray))  saving(B,replace)
graph combine A.gph B.gph,graphregion(c(white))
graph export "$folder\Draft\figures\FIGURE13.pdf", as(pdf) replace	


*****************FIGURE 14, PANEL A
use $folder\Data\clean\GID_Data_Clean_plus.dta if age>=25 & age<=55 & TW>3 & year>=1998, replace
gen temp=1-OPEN

gen atypical=temp==1|part==1

gcollapse temp part atypical,by(year y_b)
g yb=y_b+25

forvalues j=1985(5)2010 {
		g temp`j'=temp if yb==`j'
		lab var temp`j' "`j'"
		g part`j'=parttime if yb==`j'
		lab var part`j' "`j'"
		g aty`j'=atypical if yb==`j'
		lab var aty`j' "`j'"
		}

scatter temp19* temp20* year,xlabel(1998(2)2016) c(l l l l l l) graphr(c(white)) ///
 ylabel(.05(.05).35) color(red blue green black) ///
			xtitle("", size(${xtitlesize}))  ///
		ytitle("", size(${ytitlesize})) ///
		title("Share fixed-term", color(black) size(medium)) ///
		xlabel(, grid) s(oh sh th dh X oh) legend(ring(0) position(10) order(1 "1985" 2 "1990" 3 "1995" 4 "2000" 5 "2005" 6 "2010") size(medium) cols(2) symxsize(7) region(lcolor(black))) plotregion(lcolor(black)) saving(A,replace)

*****************FIGURE 14, PANEL b
use $folder\Data\clean\GID_Data_Clean_plus.dta if age>=25 & age<=55 & TW>3, replace
keep id year Yr age y_b 
xtset id year
tsfill
replace Yr=0 if Yr==.

egen minyear=min(year),by(id)
egen maxyear=max(year),by(id)

gen intermittent=Yr==0 & L.Yr>0 & L.Yr!=. & F.Yr>0 & F.Yr!=.	/*(y-Temporary exiter-y)*/
replace intermittent=. if year==minyear|year==maxyear

	egen yb=mean(y_b),by(id)
	drop y_b

	gcollapse intermittent ,by(yb year)
	replace yb=yb+25

	forvalues j=1985(5)2010	{
		gen en`j'=intermittent if yb==`j'
		lab var en`j' "`j'"
		}

	lab var year "Year"

scatter en19* en20* year,xlabel(1985(5)2015) c(l l l l l l) graphr(c(white)) ///
 ylabel(0(.02).12) color(red blue green black) ///
			xtitle("", size(${xtitlesize}))  ///
		ytitle("", size(${ytitlesize})) ///
		title("Share intermittent workers", color(black) size(medium)) ///
		xlabel(, grid) s(oh sh th dh X oh) legend(ring(0) position(10) order(1 "1985" 2 "1990" 3 "1995" 4 "2000" 5 "2005" 6 "2010") size(medium) cols(2) symxsize(7) region(lcolor(black))) plotregion(lcolor(black)) saving(B,replace)

graph combine A.gph B.gph,graphregion(c(white))
graph export "$folder\Draft\figures\FIGURE14.pdf", as(pdf) replace	



*****Figure 15
**************EXPERIENCE MINCER STUFF cohort level
use "D:\Dropbox\BDI\storico_stata\comp.dta",clear			/*SHIW data*/
keep if eta>=25 & eta<=55
keep if anasc>=1960
gen educ=0 if studio==1
replace educ=5 if studio==2
replace educ=8 if studio==3
replace educ=13 if studio==4
replace educ=18 if studio==5
replace educ=21 if studio==6
gen collegeplus=studio==5|studio==6
gcollapse educ collegeplus,by(anasc)
ren anasc yb
drop if yb==.
sort yb
save $folder\shiw_educ,replace

use $folder\Data\clean\GID_Data_Clean_plus.dta if age>=25 & age<=55 & TW>3 & y_b>=1960, replace
ren y_b yb
bys id (year): gen sumTW=sum(TW)
egen xxx=group(id firm_ID)
bys xxx (year): gen tenure=sum(TW)

gcollapse sumTW tenure,by(year yb)
sort yb
merge yb using $folder\shiw_educ
drop if _merge!=3
drop _merge
g age=year-yb

keep if age==30|age==35|age==40
ren sum E
ren ten T
ren educ S
foreach x in E T	{
	g `x'30=`x' if age==30
	g `x'35=`x' if age==35
	g `x'40=`x' if age==40
	lab var `x'30 "Age 30"
	lab var `x'35 "Age 35"
	lab var `x'40 "Age 40"
}
g S35=S if age==35

lab var S35 "Years of schooling"
drop if year<1995

scatter E35 year,c(l l l) s(oh x dh) legend(size(small) reg(lc(white)) cols(3)) graphr(c(white)) xlabel(1995(5)2015,angle(45) labsize(small)) ylabel(300(50)400) title("Experience, age 35") ytitle(Weeks) saving(a1,replace) 
scatter T35 year,c(l l l) s(oh x dh) legend(size(small) reg(lc(white)) cols(3)) graphr(c(white)) xlabel(1995(5)2015,angle(45) labsize(small)) ylabel(200(20)260) title("Tenure, age 35") saving(a2,replace) ytitle(Weeks) 
scatter S35 year,c(l l l) s(oh x dh) legend(size(small) reg(lc(white)) cols(3)) graphr(c(white)) xlabel(1995(5)2015,angle(45) labsize(small)) ylabel(10(1)13) title("Schooling, age 35") saving(a3,replace) 
graph combine a3.gph a1.gph a2.gph ,graphr(c(white)) cols(3)
graph export "$folder\Draft\figures\FIGURE15.pdf", as(pdf) replace	


*****FIGURE 16
/***** Computing the stock of human capital !!!*/
use $folder\Data\clean\GID_Data_Clean_plus.dta if age>=25 & age<=55 & TW>3 & y_b>=1960, clear

bys id (year): gen exper=sum(TW)
bys id (year): gen exper_temp=sum(TW*(1-OPEN))
bys id (year): gen exper_perm=sum(TW*OPEN)

egen xxx=group(id firm_ID)
bys xxx (year): gen tenure=sum(TW)
bys xxx (year): gen tenure_temp=sum(TW*(1-OPEN))
bys xxx (year): gen tenure_perm=sum(TW*OPEN)

g logYr=log(Yr)

g exper2=exper^2
g tenure2=tenure^2
g logweeks=log(TW) 				// weeks_worked_adj_main is zero for full time jobs!


xtreg logYr exper tenure exper2 tenure2 i.year parttime i.dim i.sect Nobs logweeks,fe		
predict u,u
predict v,ue

gegen coh_eff=mean(u),by(y_b)
gen bexp=_b[exper]
gen bten=_b[tenure]
gen bexp2=_b[exper2]
gen bten2=_b[tenure2]


	gcollapse coh_eff bexp bten exper tenure bexp2 bten2 exper2 tenure2,by(year y_b)
	ren y_b yb
	sort yb
	merge yb using $folder\shiw_educ
	g age=year-yb
	g logH_bt=bexp*exper+bten*tenure+coh_eff+bexp2*exper2+bten2*tenure2
	g logH_bt1=bexp*exper+bten*tenure+bexp2*exper2+bten2*tenure2
	g logH_bt2=coh_eff


/*Revision sept 2021*/
	su logH_bt1 if yb==1962 & year==1987		/*Normalization*/
	replace logH_bt1=logH_bt1-r(mean)
	su logH_bt2 if yb==1962 & year==1987		/*Normalization*/
	replace logH_bt2=logH_bt2-r(mean)


	forvalues j=1960(1)1991	{
		gen H`j'=logH_bt if yb==`j'
		gen H1`j'=logH_bt1 if yb==`j'
		gen H2`j'=logH_bt2 if yb==`j'
	}
	sort age
	egen maxage=max(age),by(yb)


scatter H11960 H11965 H11970 H11975 H11980 H11985 age,xlabel(25(5)55) c(l l l l l l) graphr(c(white)) ///
 ylabel(0(.05).4) color(red blue green black) ///
			xtitle("Age", size(medium))  ///
		ytitle("", size(${ytitlesize})) ///
		title("", color(black) size(medium)) ///
		xlabel(, grid) s(oh sh th dh X oh) legend(ring(0) position(10) order(1 "1985" 2 "1990" 3 "1995" 4 "2000" 5 "2005" 6 "2010") size(medium) cols(2) symxsize(7) region(lcolor(black))) plotregion(lcolor(black)) saving(a,replace) title("Human capital - explained by experience") 

	
	collapse logH_bt2,by(yb)
	replace yb=yb+25		
	lab var yb "Year of entry in labor market"
	scatter logH_bt2 yb, s(oh) graphr(c(white)) title("Human capital - explained by cohort effect",size(medium)) xlabel(1985(5)2015) ylabel(0(.05).4) ytitle("") ///
	plotregion(lcolor(black)) c(l) clp(dash) saving(b,replace)

graph combine b.gph a.gph,graphr(c(white))  
graph export "$folder\Draft\figures\FIGURE16.pdf", as(pdf) replace	


***FIGURE A.14
******
use $folder\BDI\storico_stata\ldip.dta,clear 
egen Y=rsum(ylm ylnm)
drop if mesilav==1
collapse Y, by(nq nord anno)
sort nq nord anno
save $folder\BDI\temp1.dta,replace

use $folder\BDI\storico_stata\comp.dta,clear
sort nq nord anno
merge nq nord anno using  $folder\BDI\temp1.dta
erase $folder\BDI\temp1.dta
tab _merge
keep if _merge==3
drop _merge

sort anno
merge anno using $folder\GID_QE\Data\macro\defl.dta
tab _merge
drop if _merge!=3
drop _merge

keep if eta>=25 & eta<=55
*drop if settp7==6

keep if settp9==8
gen Yr=Y/defl
gen ly=log(Yr)

gcollapse (p90) p90=ly (p10) p10=ly (p50) p50=ly,by(anno)
g p9010=p90-p10
g p9050=p90-p50
g p5010=p50-p10

lab var an Year
lab var p9010 "90-10th pctl. diff."
scatter p9010 an,c(l) s(oh) graphr(c(white)) xlabel(1985(5)2015) saving(A,replace)

lab var p9050 "90-50th pctl. diff."
lab var p5010 "50-10th pctl. diff."

scatter p9050 p5010 an,c(l l) s(oh x) clp(solid dash) graphr(c(white)) xlabel(1985(5)2015) legend(size(small)) saving(B,replace)

graph combine A.gph B.gph,graphr(c(white))
graph export "$folder\Draft\figures\FIGUREA14.pdf", as(pdf) replace
