// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
// This program generates Other figurs for draft. 
//Written by Davide Malacrino -- Feb 19 2021
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

clear all
set more off


// Organizing the work space
	global maindir ="C:\Users\Davide\Dropbox\GID_QE\analysis_core_january_2021"
	global outfolder= "For_Paper_HMP_Italy"	
	global sep =  "\"
	global folderfile = "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"
	global date_folder = "22 Jan 2021 "


// Define some common charactristics of the plots 
	global xtitlesize =   "large" 
	global ytitlesize =   "large" 
	global xlabsize =     "large" 
	global ylabsize =     "large" 
	global titlesize  =   "large" 
	global subtitlesize = "medium" 
	global formatfile  =  "pdf"
	global fontface   =   "Times New Roman"
	global marksize =     "medium"	
	global legesize =     "large"	


// Where the figs are going to be saved
	capture noisily mkdir "$maindir${sep}figs${sep}${outfolder}${sep}FigsPaper"

// do S&S file with plot programs just in case
do "$maindir${sep}do${sep}myplots.do"

********************************************************************************
// Dispersion in volatility by year:

/*- recreate the figure from slides p.13 with Sergio and Serdar's style (volatility by income percentile, at different points in time that shows the rise in volatility at lower percentiles).*/


insheet using "${maindir}${sep}out${sep}${date_folder}Volatility${sep}L_researn1F_allrank.csv", comma


	
graph set window fontface "${fontface}"


gen toplot=p90researn1f-p10researn1f
gen rank_perc=permrank

preserve			 
keep toplot rank_perc year 
reshape wide toplot, i(rank_perc) j(year)			 
tw (connected toplot1990 toplot2000 toplot2010 rank_perc , msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "1990" 2 "2000" 3 "2010") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("P90-P10 Differential of g{sub:it}", size(${ytitlesize})) ///
		title("", color(black) size(medium)) ylabel(0.2(0.2)1.6,labsize(${ylabsize})) /*yline(0,lcolor(black) lpattern(dash))*/

graph export "${folderfile}/Dispersion_vol_g1_by_year.pdf", replace 
restore

********************************************************************************

********************************************************************************
// volatility by cohort:

/*- volatility by cohort (Figure 11) in the same style as in the bottom row of Figure 7 --  maybe with different cohort choice to emphasize the transition of the labor market around 1995-2000*/

clear
insheet using "${maindir}${sep}out${sep}${date_folder}Volatility${sep}L_researn1F_age_sumstat.csv", comma

gen toplot=p90researn1f-p10researn1f

gen cohort = year-age

gen cohort_group = 1900+floor((cohort-1900)/1)*1



drop if nresearn1f==0

bys year cohort_group: gegen mean_toplot = mean(toplot) [fw = nresearn1f]
bys year cohort_group: gen tokeep=_n
keep if tokeep==1


keep mean_toplot year cohort_group
reshape wide mean_toplot , i(year) j(cohort_group)	

*generate volatility by age
cap drop volatility_at_25
cap drop volatility_at_35

gen volatility_at_25 =  mean_toplot1960
gen volatility_at_35 =  mean_toplot1950
forvalues yy = 1(1)30{
    local yob_25 = 1960 + `yy'
	local yob_35 = 1950 + `yy'
	local relevant_year = 1985 +`yy'
    replace volatility_at_25 =  mean_toplot`yob_25' if year == `relevant_year'
	replace volatility_at_35 =  mean_toplot`yob_35' if year == `relevant_year'
} 

local list_years "1960 1965 1970 1975 1980 1985" 
local listvar_plot = ""
local legend_order =""
local ii = 1
foreach yy in `list_years'{
    
    local zz `: word `ii' of `list_years''
	local listvar_plot = "`listvar_plot' mean_toplot`zz'"
	
	*use the year in which people turn 25 as a label:
	local qq = `zz' + 25
	local lab`ii' = "`qq'"
	local ii = `ii'+1
}
disp "`legend_order'"

*tw (connected mean_toplot1935 mean_toplot1950  mean_toplot1960 mean_toplot1970 mean_toplot1975  mean_toplot1980  year ,
tw (connected `listvar_plot'  year , ///
		msymbol(none none o) ///
		color(blue red black green orange olive) lpattern(solid solid solid solid solid solid) msymbol(O S T D X) ///
		mfcolor(blue*0.25 red*0.25 black*0.25 green*0.25 orange*0.25 olive*0.25) ) ///
		(connected volatility_at_25 volatility_at_35 year, lpattern(dash dash) color(gs9 gs9) msymbol(none none))  ///
		(pcarrowi 0.25 1990 0.5 1992, msize(${legesize}) mlwidth(medthick) mlcolor(black) lcolor(black) ) ///
		(pcarrowi 1.5 2003 1.4 2006, msize(${legesize}) mlwidth(medthick) mlcolor(black) lcolor(black) ) , ///
		text(0.25 1990 "35 yrs old", place(w) size(${legesize})) ///
		text(1.5 2003 "25 yrs old", place(w) size(${legesize})) ///
		graphregion(color(white)) /// Legend options 
		graphregion(color(white)  ) ///				Graph region define
		plotregion(lcolor(blaxck))  ///				Plot regione define
		xtitle("") xlabel(1985(5)2015, labsize($xlabsize) grid) ///
		ytitle("P90-P10 Differential of g{sub:it}", size(${xtitlesize})) ylabel(, labsize($xlabsize)) ///
		legend(size($legesize) symxsize(7) ring(0) position(11) col(2) order(1 "`lab1'" 2 "`lab2'" 3 "`lab3'" 4 "`lab4'" 5 "`lab5'" 6 "`lab6'"))
graph export "${folderfile}/Dispersion_vol_g1_by_cohort.pdf", replace 	


cap drop hat*
reg volatility_at_25 year if year<1998
predict hat_v25, xb
reg volatility_at_35 year if year<1998
predict hat_v35, xb

tw (connected hat_v25 hat_v35  year , ///
		msymbol(none none o) ///
		color(blue red black green orange olive) lpattern(solid solid solid solid solid solid) msymbol(O S T D X) ///
		mfcolor(blue*0.25 red*0.25 black*0.25 green*0.25 orange*0.25 olive*0.25) ) ///
		(connected volatility_at_25 volatility_at_35 year, lpattern(dash dash) color(gs11 gs6) msymbol(none none))  ///
		(pcarrowi 0.25 1990 0.5 1992, msize(${legesize}) mlwidth(medthick) mlcolor(black) lcolor(black) ) ///
		(pcarrowi 1.5 2003 1.4 2006, msize(${legesize}) mlwidth(medthick) mlcolor(black) lcolor(black) ) , ///
		text(0.25 1990 "35 yrs old", place(w) size(${legesize})) ///
		text(1.5 2003 "25 yrs old", place(w) size(${legesize})) ///
		graphregion(color(white)) /// Legend options 
		graphregion(color(white)  ) ///				Graph region define
		plotregion(lcolor(blaxck))  ///				Plot regione define
		xtitle("") xlabel(1985(5)2015, labsize($xlabsize) grid) ///
		ytitle("P90-P10 Differential of g{sub:it}", size(${xtitlesize})) ylabel(, labsize($xlabsize)) ///
		legend(size($legesize) symxsize(7) ring(0) position(5) col(2) order(1 "vol at 25 (pred.)" 2 "vol at 35 (pred.)" 3 "vol at 25" 4 "vol at 35"))
graph export "${folderfile}/Dispersion_vol_g1_predictions.pdf", replace 	



********************************************************************************
// inequality by cohort all

clear
insheet using "${maindir}${sep}out${sep}${date_folder}Inequality${sep}L_logearn_age_sumstat.csv", clear
global vari "logearn"
	*Calculate additional moments 
	gen p99990${vari} = p99_9${vari} - p99${vari}
	gen p9990${vari} = p99${vari} - p90${vari}
	gen p9010${vari} = p90${vari} - p10${vari}	
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}

	*Gen cohort that is the age at which cohort was 25 years old 
	gen cohort25 = year - age + 25
	order year age cohort25


	foreach cc in 1985 1995 2005 2010{
		cap drop aux_`cc'
		gen aux_`cc' = p9010logearn
		replace aux_`cc' = . if cohort25!=`cc'
	}
	
	
tw (connected aux_* year , msymbol(none none o) ///
		color(blue red black green orange olive) lpattern(solid solid solid solid solid solid) msymbol(O S T D X) ///
		mfcolor(blue*0.25 red*0.25 black*0.25 green*0.25 orange*0.25 olive*0.25) ) ///
	(line p9010logearn year if age==25, lpattern(dash) color(gs11) msymbol(none)) ///
	(line p9010logearn year if age==35 & year>1994, lpattern(dash) color(gs6) msymbol(none)) /// 
	(pcarrowi 1.7 1996 1.83 1997, msize(${legesize}) mlwidth(medthick) mlcolor(black) lcolor(black) ) ///
	(pcarrowi 2.1 2003 2.05 2005, msize(${legesize}) mlwidth(medthick) mlcolor(black) lcolor(black) ) , ///
	text(1.7 1996 "35 yrs old", place(w) size(${legesize})) ///
	text(2.1 2003 "25 yrs old", place(w) size(${legesize})) ///
	plotregion(lcolor(blaxck))  ///				Plot regione define
	graphregion(color(white)) ///
	xtitle("") xlabel(1985(5)2015, labsize($xlabsize) grid) ///
	ytitle("P90-P10 Differential of Log Earnings", size(${xtitlesize})) ylabel(1.3(0.2)2.5, labsize($xlabsize)) ///
	legend(size($legesize) symxsize(7) ring(0) position(5) col(2) order(1 "vol at 25 (pred.)" 2 "vol at 35 (pred.)" 3 "vol at 25" 4 "vol at 35"))
graph export "${folderfile}/fig3b_all_logearn.pdf", replace 	
	

	
	
	

********************************************************************************
// volatility in figure 7 all + skewness and excess kurtosis


*insheet using "out${sep}${voladata}${sep}L_${vari}_male_sumstat.csv", case clear

clear
insheet using "${maindir}${sep}out${sep}${date_folder}Volatility${sep}L_researn1F_sumstat.csv", clear
global vari "researn"

	gen p9050$vari = p90$vari - p50$vari
	gen p5010$vari = p50$vari - p10$vari
	gen p9010$vari = p90$vari - p10$vari


tw (connect p9010$vari p9010$vari year, mcol(navy navy) lcol(navy navy)), graphregion(color(white)) plotregion(lcolor(blaxck)) ///
		ytitle("Dispersion of g{sub:it}") legend(order(2 "P90-P10") symxsize(7) ring(0) position(10) col(2) size($legesize))
graph export "${folderfile}/fig4_DM_p90p10_all_researn.pdf", replace 


tw (connect p9050$vari p5010$vari year), graphregion(color(white)) graphregion(color(white)) plotregion(lcolor(blaxck)) ///
		ytitle("Dispersion of g{sub:it}") legend(order(1 "P90-P50" 2 "P50-P10") symxsize(7) ring(0) position(10) col(2) size($legesize))
graph export "${folderfile}/fig4_all_researn.pdf", replace 


	gen ksk${vari} = ((p90${vari} - p50${vari}) - (p50${vari} - p10${vari}) )/(p90$vari - p10${vari})
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/(p75$vari - p25${vari}) - 2.91
	
	
	

tw (connect ksk$vari year), graphregion(color(white)) ytitle("Skewness of g{sub:it}") graphregion(color(white)) plotregion(lcolor(blaxck))
graph export "${folderfile}/fig5A_ALL_researn1F.pdf", replace 


tw (connect cku$vari year), graphregion(color(white)) ytitle("Excess Kurtosis of g{sub:it}") graphregion(color(white)) plotregion(lcolor(blaxck))
graph export "${folderfile}/fig5B_ALL_researn1F.pdf", replace 



********************************************************************************
//  Volatility and asymmetrical and central tendencies of earning growth by income. The figures are obtained pooling together the latest 20 years of data.

clear
insheet using "${maindir}${sep}out${sep}${date_folder}Volatility${sep}L_researn1F_agerank.csv", clear
global vari "researn"

		gen p9010${vari} = p90${vari} - p10${vari}
		gen p9050${vari} = p90${vari} - p50${vari}
		gen p5010${vari} = p50${vari} - p10${vari}
		gen p7525${vari} = p75${vari} - p25${vari}
		gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
		gen cku${vari} = (p97_5${vari} - p2_5${vari})/p7525${vari} - 2.91		// Excess Kurtosis
		replace kurt${vari} = kurt${vari} - 3.0		// Excess Kurtosis

		collapse  p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, by(agegp permrank)
		reshape wide p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, i(permrank) j(agegp)
		
		
		gen idex = _n
		order idex 
		
		
		tw (connected p9010${vari}1 p9010${vari}2 p9010${vari}3 permrank if idex<=42 & permrank<100 , msymbol(none none o)  ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize})) ///
		ytitle("P90-P10 Differential of g{sub:it}", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) 
graph export "${folderfile}/fig6A_ALL_researn1F.pdf", replace 	

		tw (connected ksk${vari}1 ksk${vari}2 ksk${vari}3 permrank if idex<=42 & permrank<100, msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Kelley Skewness of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize}))  yline(0,lcolor(black) lpattern(dash))
graph export "${folderfile}/fig6B_ALL_researn1F.pdf", replace 			
		
		tw (connected cku${vari}1 cku${vari}2 cku${vari}3 permrank if idex<=42 & permrank<100, msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(11) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Excess Crow-Siddiqui Kurtosis of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(medium)) ylabel(2(2)14)
graph export "${folderfile}/fig6C_ALL_researn1F.pdf", replace 		

